import { Schedule } from 'aws-cdk-lib/aws-events';
import { Policy } from 'aws-cdk-lib/aws-iam';
import { Architecture } from 'aws-cdk-lib/aws-lambda';
import { Construct } from 'constructs';
import { LogLevel } from './log-levels';
/**
 * Properties for a MonthlyCostNotifier.
 */
export interface MonthlyCostNotifierProps {
    /**
     * The webhook to post to.
     */
    readonly webhook: string;
    /**
     * The accountId this is being deployed to.
     */
    readonly accountId: string;
    /**
     * The eventbridge rule name
     *
     * @default MonthlyCostNotifierRule
     */
    readonly ruleName?: string;
    /**
     * The eventbridge rule schedule
     *
     * @default - { minute: '0', hour: '15', day: '1', month: '*', year: '*' }
     */
    readonly ruleSchedule?: Schedule;
    /**
     * The lambda name
     *
     * @default MonthlyCostNotifier
     */
    readonly lambdaName?: string;
    /**
     * The lambda log level
     *
     * @default MonthlyCostNotifier
     */
    readonly lambdaLogLevel?: LogLevel;
    /**
     * An additional policy to attach to the lambda
     *
     * @default none
     */
    readonly lambdaRolePolicy?: Policy;
    /**
     * The lambda architecture
     *
     * @default ARM_64
     */
    readonly lambdaArchitecture?: Architecture;
}
/**
 * A construct that creates a lambda function bundled with the 'monthly-notifier-lambda' code
 * This is trigger via eventbridge on a schedule to post to a discord webhook for the monthly costts
 *
 * WARNING: This lambda uses a pay per request API. Each call to cost explorer costs $0.01 USD.
 */
export declare class MonthlyCostNotifier extends Construct {
    constructor(scope: Construct, id: string, props: MonthlyCostNotifierProps);
}
